@@ -9,6 +9,7 @@ from scipy.stats import norm
 from sklearn.model_selection import train_test_split 
 from sklearn.linear_model import LinearRegression
 from sklearn import metrics
+from fbprophet import Prophet
 
 def prep_dataframe(file):
     sales = pd.read_csv(file)
@@ -322,4 +323,62 @@ def seasonalityIndexPerProduct(file,product_number,year):
     seationality_index_year['year'] = year
     seationality_index_year.reset_index()
     seationality_index_year.to_csv('SeasonalityIndexPerProduct.csv', index = False)
-    print("Seasonality Index Per Product", seationality_index_year, sep='\n')
\ No newline at end of file
+    print("Seasonality Index Per Product", seationality_index_year, sep='\n')
+    
+def forecastQtyMonthlySales(file,product_number,months):
+    sales = prep_dataframe(file)
+    forecastDF = sales.loc[sales['product_number'] == product_number]
+    forecastDF['sales'] = forecastDF['price']*forecastDF['quantity']
+    forecastDF = forecastDF[['date','sales']]
+    forecastDF['index'], forecastDF['month_year'] = pd.to_datetime(forecastDF['date']).dt.to_period('M'), pd.to_datetime(forecastDF['date']).dt.to_period('M')
+    forecastDF = forecastDF[['index','month_year','sales']]
+    forecastDF.set_index('index', inplace=True)
+    forecastDF = forecastDF.groupby('month_year', as_index=False).agg({"sales": "sum"})
+    forecastDF = forecastDF.rename(index=str, columns={"sales": "y", "month_year": "ds"})
+    forecastDF['ds'] = forecastDF.ds.values.astype('datetime64[M]')
+    bev_model = Prophet(interval_width=0.95)
+    bev_model.fit(forecastDF)
+    future_dates = bev_model.make_future_dataframe(periods=months, freq='M')
+    forecast = bev_model.predict(future_dates)
+    print('Forecast Metrics: ')
+    print(forecast[['ds', 'yhat', 'yhat_lower', 'yhat_upper']].tail(months))
+    print('Forecast Graph: ')
+    bev_model.plot(forecast, uncertainty=True);
+    
+def forecastMonthlyPrice(file,product_number,months):
+    sales = prep_dataframe(file)
+    forecastDF = sales.loc[sales['product_number'] == product_number]
+    forecastDF = forecastDF[['date','price']]
+    forecastDF['index'], forecastDF['month_year'] = pd.to_datetime(forecastDF['date']).dt.to_period('M'), pd.to_datetime(forecastDF['date']).dt.to_period('M')
+    forecastDF = forecastDF[['index','month_year','price']]
+    forecastDF.set_index('index', inplace=True)
+    forecastDF = forecastDF.groupby('month_year', as_index=False).agg({"price": "mean"})
+    forecastDF = forecastDF.rename(index=str, columns={"price": "y", "month_year": "ds"})
+    forecastDF['ds'] = forecastDF.ds.values.astype('datetime64[M]')
+    bev_model = Prophet(interval_width=0.95)
+    bev_model.fit(forecastDF)
+    future_dates = bev_model.make_future_dataframe(periods=months, freq='M')
+    forecast = bev_model.predict(future_dates)
+    print('Forecast Metrics: ')
+    print(forecast[['ds', 'yhat', 'yhat_lower', 'yhat_upper']].tail(months))
+    print('Forecast Graph: ')
+    bev_model.plot(forecast, uncertainty=True);
+    
+def forecastMonthlyCost(file,product_number,months):
+    sales = prep_dataframe(file)
+    forecastDF = sales.loc[sales['product_number'] == product_number]
+    forecastDF = forecastDF[['date','cost']]
+    forecastDF['index'], forecastDF['month_year'] = pd.to_datetime(forecastDF['date']).dt.to_period('M'), pd.to_datetime(forecastDF['date']).dt.to_period('M')
+    forecastDF = forecastDF[['index','month_year','cost']]
+    forecastDF.set_index('index', inplace=True)
+    forecastDF = forecastDF.groupby('month_year', as_index=False).agg({"cost": "mean"})
+    forecastDF = forecastDF.rename(index=str, columns={"cost": "y", "month_year": "ds"})
+    forecastDF['ds'] = forecastDF.ds.values.astype('datetime64[M]')
+    bev_model = Prophet(interval_width=0.95)
+    bev_model.fit(forecastDF)
+    future_dates = bev_model.make_future_dataframe(periods=months, freq='M')
+    forecast = bev_model.predict(future_dates)
+    print('Forecast Metrics: ')
+    print(forecast[['ds', 'yhat', 'yhat_lower', 'yhat_upper']].tail(months))
+    print('Forecast Graph: ')
+    bev_model.plot(forecast, uncertainty=True);
\ No newline at end of file
